#! /bin/sh
#
# Usage:        batch2.sh install_arguments
#
# Abstract:     This Bourne Shell script performs a client 
#		(type 2) type of installation in batch.
#
# Options:
#		install_arguments - arguments simply passed on without
#				    parsing to install_matlab.
#
# Note(s):	1. Supply values for the right hand side for the
#		   following 6 variables in this script. See the
#		   README in the MATLAB ./install directory for further
#		   explanation.
#
#                  WATCH OUT!
#
#                  If the MATLAB root directory is part of an AUTOMOUNTED
#                  directory supply a directory path for MATLAB that does
#                  not include any mount point information. It must be a
#                  path that forces a mount to be done if it is currently
#                  unmounted.
#
#		   MATLAB=
#		   OUTPUT_FILE=
#		   WANT_ACCESS_DIR=		yes OR no
#		   ACCESS_DIR=
#		   WANT_MAN_PAGES=		yes OR no
#		   MAN_PAGES_DIR=
#
#		   NO BLANKS around the "=" in the assignments!
#
#		2. Run this script as root.
#
#               3. If this routine is sourced then the variable arglist
#                  contains any extra arguments to be passed to
#                  install_matlab. arglist should never be the empty
#                  string even when there are no arguments.
#
# Example:	1. Here is a sample dataset
#
#		   MATLAB=/usr/local/matlab  
#		   OUTPUT_FILE=/tmp/install2.out
#		   WANT_ACCESS_DIR=yes
#		   ACCESS_DIR=/usr/local/bin
#		   WANT_MAN_PAGES=no
#		   MAN_PAGES_DIR=
#
# Copyright (c) 1992-94 by The MathWorks, Inc.
# $Revision: 1.9 $  $Date: 1994/10/17 20:18:23 $
#----------------------------------------------------------------------------
#+++++++++++++++ substitute right hand values as required ++++++++++++++++++
#
    MATLAB=
    OUTPUT_FILE=
    WANT_ACCESS_DIR=
    ACCESS_DIR=
    WANT_MAN_PAGES=
    MAN_PAGES_DIR=
#
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#    
    trap "rm -rf /tmp/$$a > /dev/null 2>&1; exit" 0 1 2 3 15
#
    DOLLAR_MATLAB='$MATLAB'
    if [ "$arglist" = "" ]; then
        cat > /tmp/$$a << EOF
#
# MATLAB installation: client
#
MATLAB=$MATLAB
$DOLLAR_MATLAB/install_matlab $* -b 2 > $OUTPUT_FILE 2>&1 << EOF
$MATLAB
EOF
    else
        cat > /tmp/$$a << EOF
#
# MATLAB installation: client
#
MATLAB=$MATLAB
$DOLLAR_MATLAB/install_matlab $arglist -b 2 > $OUTPUT_FILE 2>&1 << EOF
$MATLAB
EOF
    fi
#
    if [ `expr "//$WANT_ACCESS_DIR" : '//[Nn].*'` -gt 0 ]; then
        cat >> /tmp/$$a << EOF
$WANT_ACCESS_DIR
EOF
    else
        cat >> /tmp/$$a << EOF
$WANT_ACCESS_DIR
$ACCESS_DIR
EOF
    fi
#
    if [ `expr "//$WANT_MAN_PAGES" : '//[Nn].*'` -gt 0 ]; then
        cat >> /tmp/$$a << EOF
$WANT_MAN_PAGES
EOF
    else
        cat >> /tmp/$$a << EOF
$WANT_MAN_PAGES
$MAN_PAGES_DIR
EOF
    fi
#
    cat >> /tmp/$$a << EOF2
EOF
EOF2
#
    . /tmp/$$a
