% Image Processing Toolbox.
% Version 1.0b  31-Jan-94
%
% Image input/output.
%   bmpread    - Read a BMP (Microsoft Windows Bitmap) file from disk.
%   bmpwrite   - Write a BMP (Microsoft Windows Bitmap) file to disk.
%   gifread    - Read a GIF (Graphics Interchange Format) file from disk.
%   gifwrite   - Write a GIF (Graphics Interchange Fromat) file to disk.
%   hdfpeek    - List object tag/ref pairs in HDF file.
%   hdfread    - Read data from HDF file.
%   hdfwrite   - Write data to HDF file.
%   pcxread    - Read a PCX (ZSoft Paint Format) file from disk.
%   pcxwrite   - Write a PCX (ZSoft Paint Format) file to disk.
%   tiffread   - Read a TIFF (Tagged Image File Format) file from disk.
%   tiffwrite  - Write a TIFF (Tagged Image File Format) file to disk.
%   xwdread    - Read a XWD (X window dump) file from disk.
%   xwdwrite   - Write a XWD (X window dump) file to disk.
% 
% Utility routines.
%   getimage   - Get image data from axes.
%   isbw       - True for black and white images.
%   isgray     - True for intensity images.
%   isind      - True for indexed images.
%
% Color operations.
%   brighten   - Brighten or darken a colormap (MATLAB Toolbox).
%   cmunique   - Find unique colormap colors and corresponding image.
%   cmpermute  - Permute colormap positions.
%   cmgamma    - Gamma correct colormap.
%   cmgamdef   - Default gamma correction table.
%   dither     - Floyd-Steinberg image dithering.
%   hsv2rgb    - Convert HSV values to RGB colorspace (MATLAB Toolbox).
%   imadjust   - Adjust and stretch image intensity.
%   imapprox   - Approximate indexed image by an image with fewer colors.
%   ntsc2rgb   - Convert NTSC values to RGB colorspace.
%   rgb2gray   - Convert RGB values to gray.
%   rgb2hsv    - Convert RGB values to HSV colorspace (MATLAB Toolbox).
%   rgb2ntsc   - Convert RGB values to NTSC colorspace.
%   rgbplot    - Plot RGB colormap components (MATLAB Toolbox).
% 
% Geometric operations.
%   imcrop     - Crop image.
%   imresize   - Resize image.
%   imrotate   - Rotate image.
%   truesize   - Resize figure so that image is actual size.
%   imzoom     - Zoom in and out an image or 2-D plot.
% 
% Image enhancement/analysis
%   brighten   - Brighten or darken a colormap (MATLAB Toolbox).
%   grayslice  - Density (intensity) slicing.
%   histeq     - Histogram equalization.
%   imadjust   - Adjust and stretch image intensity.
%   imapprox   - Approximate indexed image by an image with fewer colors.
%   imhist     - Image histogram.
%   impixel    - Color of a pixel.
%   improfile  - Intensity profile.
%   interp2    - Two-dimensional data interpolation (MATLAB Toolbox).
% 
% Image statistics.
%   mean2      - Mean of a matrix.
%   corr2      - Two-dimensional correlation coefficient.
%   std2       - Two-dimensional standard deviation.
% 
% Morphological operations.
%   bwarea     - Area of objects in binary image.
%   dilate     - Dilate (thicken) a binary image.
%   erode      - Erode (thin) a binary image.
%   edge       - Edge extraction.
%   bweuler    - Euler number.
%   bwmorph    - Morphological operators.
%   bwperim    - Perimeter of objects in a binary image.
% 
% FIR Filter design.
%   fsamp2     - 2-D FIR filter design via frequency sampling.
%   fspecial   - Special 2-D filters.
%   ftrans2    - 2-D FIR filter design via frequency transformation.
%   fwind1     - 2-D FIR filter design using 1-D windows.
%   fwind2     - 2-D FIR filter design using 2-D windows.
%   imnoise    - Image noise.
% 
% Frequency response.
%   freqspace  - Frequency spacing for 2-D frequency responses.
%   freqz2     - Two dimensional frequency response.
% 
% Filtering.
%   colfilt    - Local non-linear filtering as columns.
%   conv2      - Two-dimensional convolution (MATLAB Toolbox).
%   filter2    - Two-dimensional filtering (MATLAB Toolbox).
%   medfilt2   - Two-dimensional median filtering.
%   mfilter2   - Masked filter.
%   nlfilter   - Local non-linear filtering.
%   wiener2    - Adaptive 2-D Wiener filtering.
% 
% Block processing.
%   bestblk    - Best block size for block processing.
%   blkproc    - Process an image in blocks.
%   col2im     - Rearrange distinct or sliding column blocks to form image.
%   colfilt    - Local non-linear filtering as columns.
%   im2col     - Rearrange distinct or sliding blocks into columns.
% 
% Region of interest (ROI).
%   mfilter2   - Masked filter.
%   roipoly    - Define polygonal region of interest (ROI).
%   roicolor   - Define region of interest (ROI) by color.
% 
% Transforms.
%   dct2       - Two-dimensional discrete cosine transform.
%   fft2       - Two-dimensional Fast Fourier Transform (MATLAB Toolbox).
%   fftshift   - Move zeroth lag (DC component) to center (MATLAB Toolbox).
%   idct2      - Two-dimensional inverse discrete cosine transform.
%   ifft2      - Two-dimensional inverse FFT (MATLAB Toolbox).
%   radon      - Radon transform.
% 
% Conversions.
%   dither     - Floyd-Steinberg image dithering.
%   gray2ind   - Convert gray scale intensity image to indexed image.
%   hsv2rgb    - Convert HSV values to RGB colorspace (MATLAB Toolbox).
%   im2bw      - Convert image to black and white by thresholding.
%   imslice    - Get/put image slices into an image deck.
%   ind2gray   - Convert indexed image to gray intensity image.
%   ind2rgb    - Convert indexed image to an RGB image.
%   mat2gray   - Convert matrix to (gray) intensity image.
%   ntsc2rgb   - Convert NTSC values to RGB colorspace.
%   rgb2gray   - Converts an RGB image or values to gray.
%   rgb2hsv    - Convert RGB values to HSV colorspace (MATLAB Toolbox).
%   rgb2ind    - Convert RGB image to indexed image.
%   rgb2ntsc   - Convert RGB values to NTSC colorspace.
% 
% Image display.
%   colorbar   - Display color bar (color scale).
%   colormap   - Set or get the color look-up table (MATLAB Toolbox).
%   gray       - Linear gray-scale color map (MATLAB Toolbox).
%   hsv,hot,jet- Colormaps.  Type HELP COLOR for others (MATLAB Toolbox).
%   image      - Display indexed image (MATLAB Toolbox).
%   imagesc    - Scale data and display as image (MATLAB Toolbox).
%   imcontour  - Image coutour.
%   immovie    - Make a movie of an image deck.
%   imshow     - Display all types of image data.
%   montage    - Display an image deck as a rectangular montage.
%   subimage   - Display multiple images.
%   warp       - Warp an image onto a surface.
%
% Demonstrations.
%   imdemo     - General image processing demo.
%   dctdemo    - 2-D DCT image compression demo.
%   firdemo    - 2-D FIR filtering demo.
%   nlfdemo    - 2-D Non-linear filtering demo.

% Private functions
%   cumsum3d   - Cumulative sum on 3D matrix packed in a 2D matrix.
%   dct        - 1-D Discrete Cosine Transform.
%   dctmtx2    - Unitary 2-D DCT transform matrix.
%   ditherc    - Mex file for image dithering.
%   elem3d     - Element positions of 3-D matrix packed in 2-D matrix.
%   getline    - Track mouse movement with rubberbanded line.
%   getpts     - Track mouse movement with visible points.
%   getrect    - Track mouse movement with rubberbanded rectangle.
%   gif        - Compress GIF data.
%   hdfreadc   - Mex file for reading HDF files.
%   hdfpeekc   - Mex file for peeking in HDF files.
%   hdfwc      - Mex file for writing HDF files.
%   idct       - 1-D Inverse Discrete Cosine Transform.
%   im2gray    - Convert images to gray.
%   imhistc    - Mex file for image histogram calculation.
%   ndx3d      - Index into 3-D matrix packed in a 2-D matrix.
%   rgb2im     - Convert RGB images to indexed or intensity images.
%   rle        - Compress run-length encoded data.
%   size3d     - Size of 2-D matrix to hold 3-D matrix.
%   tiff       - Compress tiff rle data.
%   ungif      - Decompress GIF data.
%   unrle      - Uncompress run-length encoded data.
%   untiff     - Decompress tiff rle data.
%   vmquant    - M-file interface to color quantization mex file.
%   vmquantc   - Mex file for color quantization.
%   waitbar    - Display waitbar

% MAT-files
%   bwmorph.mat - Look up tables for bwmorph.m
%   forest.mat  - Scanned photo of Carmanah Old Growth Forest.
%   mri.mat     - Magnetic Resonance Images of a Man's Head
%   trees.mat   - Scanned image of "Trees with a view" by Susan Cohen.

% Copyright (c) 1993-94 by The MathWorks, Inc.
% $Revision: 1.43.1.1 $  $Date: 1994/04/04 18:20:56 $
