% The MATLAB Expo and other demonstrations.
%
% MATLAB/Introduction.
%   expo, demo	- Start up The MATLAB Expo and display splash screen.
%   expomap     - Open the MATLAB Expo Main Map (avoids Expo splash screen).
%
% MATLAB/Matrices.
%   intro       - Introduction to MATLAB.
%   inverter    - Demonstrate the inversion of a matrix.
%   buckydem    - Connectivity graph of the Buckminster Fuller geodesic dome.
%   sparsity    - Demonstrate effect of sparsity orderings.
%   matmanip    - Introduction to matrix manipulation.
%   delsqdemo   - Finite difference Laplacian on various domains.
%   sepdemo     - Separators for a finite element mesh.
%   airfoil     - Display sparse matrix from NASA airfoil.
%
% MATLAB/Numerics.
%   funfuns     - Demonstrate functions that operate on other functions.
%   fitdemo     - Nonlinear curve fit with simplex algorithm.
%   sunspots    - The answer is 11.08, what is the question?
%   e2pi        - Which is greater, e^pi or pi^e?
%   bench       - MATLAB Benchmark.
%   odedemo     - Ordinary differential equations.
%   quaddemo    - Adaptive quadrature.
%   zerodemo    - Zerofinding with fzero.
%   fplotdemo   - Plot a function.
%   eigmovie    - Symmetric eigenvalue movie.
%   rrefmovie   - Computation of Reduced Row Echelon Form.
%   fftdemo     - Use of the fast finite Fourier transform.
%   quake       - Loma Prieta Earthquake.
%   census      - Try to predict the US population in the year 2000.
%   spline2d    - Demonstrate GINPUT and SPLINE in two dimensions.
%
% MATLAB/Visualization.
%   graf2d      - Demonstrate XY plots in MATLAB.
%   graf2d2     - Demonstrate XYZ plots in MATLAB.
%   grafcplx    - Demonstrate complex function plots in MATLAB.
%   lorenz      - Plot the orbit around the Lorenz chaotic attractor.
%   xpsound     - Demonstrate MATLAB V4's sound capability.
%   vibes       - Vibrating L-shaped membrane.
%   xpklein     - Klein bottle demo.
%   xfourier    - Graphics demo of Fourier series expansion.
%   cplxdemo    - Maps of functions of a complex variable.
%   peaks       - A sample function of two variables.
%   membrane    - Generate MathWorks's logo.
%   penny       - Several views of the penny data.
%   earthmap    - View Earth's topography.
%   sqdemo      - Superquadrics using UIControls.
%   imagedemo   - Demonstrate MATLAB V4's image capability.
%   colormenu   - Select color map.
%
% MATLAB/Language.
%   xplang      - Introduction to the MATLAB language.
%   graf3d      - Demonstrate Handle Graphics for surface plots.
%   hndlgraf    - Demonstrate Handle Graphics for line plots.
%   hndlaxis    - Demonstrate Handle Graphics for axes.
%
% SIMULINK/Simple Systems.
%   simintro    - A quick introduction to SIMULINK.
%   libintro    - A quick introduction to the SIMULINK Libraries.
%   simppend    - SIMULINK system modeling a simple pendulum.
%   onecart     - SIMULINK system modeling a mass-spring system.
%   bounce      - SIMULINK system modeling a bouncing ball.
%   vdp	        - SIMULINK system modeling the Van der Pol equations.
%
% SIMULINK/Complex Systems.
%   dblcart1    - SIMULINK system modeling a mass-spring system.
%   dblpend1    - SIMULINK system modeling a double-pendulum system.
%   dblpend2    - SIMULINK system modeling a double-pendulum system.
%   penddemo    - SIMULINK system modeling an inverted pendulum.
%   dblcart     - SIMULINK system modeling a double-cart system.
%   thermo      - SIMULINK system modeling a thermostat heating a house.
%   f14	        - SIMULINK system modeling an aircraft in flight.
%
% SIMULINK/Advanced Products.
%   xpaccel     - Provide information about the SIMULINK Accelerator.
%   ccodegen    - Provide information about the C-Code Generator.
%
% Toolbox/Signal Processing.
%   filtdem     - Signal Processing filter demo.
%   filtdem2    - Demonstrate filter design techniques.
%   sigdemo1    - Discrete-time Fourier transform of a signal.
%   sigdemo2    - Continuous-time Fourier transform of a signal.
%   phone       - Signal processing and the touch-tone phone.
%
% Toolbox/System Identification.
%   sysiddm     - Identify "hairdryer" system characteristics.
%   iddems      - Set up System Identification command line demos.
%
% Toolbox/Optimization.
%   bandem      - Banana function minimization demonstration.
%   optdems     - Set up Optimization command line demos.
%
% Toolbox/Neural Networks.
%   bckprp12    - Demonstrate backpropagation.
%   bckprp62    - Demonstrate backpropagation with momentum.
%   neural      - Neural network character recognition.
%
% Toolbox/Control System.
%   dskdemo     - Build controller for a disk read/write head.
%   ctrldems    - Set up Control System command line demos.
%
% Toolbox/Robust Control.
%   accdm2      - Demo of the 1990 ACC benchmark.
%   rctdems     - Set up Robust Control command line demos.
%
% Toolbox/Mu-Analysis and Synthesis.
%   xpmu        - Description of the Mu-Analysis and Synthesis process.
%   mudems      - Set up Mu-Analysis and Synthesis command line demos.
%
% Toolbox/Spline.
%   spapidm2    - Demonstrate spline interpolation.
%   spldems     - Set up Spline command line demos.
%
% Toolbox/Symbolic Math.
%   xpcalc      - Calculus operations.
%   xpgiv       - Givens transformation.
%
% Toolbox/Image Processing.
%   xpimage     - Demonstrate some Image Processing capabilities.
%
% Toolbox/Statistics.
%   xppolytl    - Interactively fit a polynomial to noisy data.
%   statdems    - Set up Statistics command line demos.
%
% Extras/Gallery.
%   knot        - Tube surrounding a three-dimensional knot.
%   quivdemo    - Demonstrate the quiver function.
%   modes       - Plot 12 modes of the L-shaped membrane.
%   logo        - Display the MATLAB L-shaped membrane logo.
%   klein1      - Construct a Klein bottle.
%   cruller     - Construct cruller.
%   tori4       - Construct four linked tori.
%   spharm2     - Construct spherical surface harmonic.
%
% Extras/Games.
%   xpbombs     - Minesweeper game.
%   life        - Conway's Game of Life.
%   bblwrap     - Bubblewrap.
%
% Extras/Miscellaneous.
%   truss       - Animation of a bending bridge truss.
%   travel      - Traveling salesman problem.
%   wrldtrv     - Great circle flight routes around the globe.
%   makevase    - Generate and plot a surface of revolution.
%   logospin    - Movie of The MathWorks' logo spinning.
%   crulspin    - Spinning cruller movie.
%   xpquad      - Superquadrics plotting demonstration.
%   spinner     - Colorful lines spinning through space.
%
% Extras/Contact Info.
%   contact1    - How to reach The MathWorks, Inc.
%   contact2    - How to reach The MathWorks, Inc. by email.
%   contact3    - How to reach international agents for The MathWorks, Inc.
%   agents      - International distributors' locations and contact information.

% General Expo/Helper functions.
%   expomenu    - Initializes Expo menubar.
%   cmdlnwin    - An Expo gateway routine for playing command line demos.
%   existtb     - Tests for the availability of individual toolboxes by name.
%   helpfun     - Utility function for displaying help text conveniently.
%   hlpmaker    - An Expo help-making utility.
%   pltmat      - Display a matrix in a figure window.
%
% MATLAB/Helper functions.
%   bucky       - The graph of the Buckminster Fuller geodesic dome.
%
% SIMULINK/Helper functions.
%   animinit    - Initializes a figure for SIMULINK animations.
%   crtanim1    - S-function for animating the motion of a mass-spring system.
%   crtanim2    - S-function for animating the motion of a mass-spring system.
%   simcad      - The SIMULINK system caddy.

% Copyright (c) 1984-94 by The MathWorks, Inc.
