% Optimization Toolbox.
% Version 1.0d 1-Mar-94
%
% Nonlinear minimization of functions.
%   attgoal    - Multi-objective goal attainment.
%   constr     - Constrained minimization.
%   fmin       - Unconstrained minimization, scalar case.
%   fminu      - Unconstrained minimization using gradient search.
%   fmins      - Unconstrained minimization using simplex search.
%   fsolve     - Nonlinear equation solution.
%   leastsq    - Nonlinear least squares.
%   minimax    - Minimax solution.
%   seminf     - Semi-infinite minimization.
%
% Minimization of matrix problems.
%   lp         - Linear programming.
%   qp         - Quadratic programming.
%   nnls       - Non-negative least squares.
% 
% Controlling defaults and options.
%   foptions   - Parameter settings.
%
% Demonstrations.
%   optdemo    - Demonstration menu.
%   tutdemo    - Tutorial walk-through.
%   bandemo    - Minimization of banana function.
%   goaldemo   - Goal attainment.
%   dfildemo   - Finite-precision filter design.
%   datdemo    - Fitting data to a curve.

% Internally Used Utility Routines
%
%   Cubic Interpolation Routines
%   cubic      - interpolates four points to find the maximum value
%   cubici1    - interpolates 2 pts and gradients to estimate minimum
%   cubici2    - interpolates 3 points and 1 gradient
%   cubici3    - interpolates 2 pts and gradients to find step and min
%
%   Quadratic Interpolation Routines
%   quad2      - interpolates three points to find the maximum value
%   quadinter  - interpolates three points to estimate minimum
%
%   Demonstration Utility Routines
%   eigfun     - function to return sorted eigenvalues (used in goaldemo)
%   elimone    - eliminates a variable (used by dfildemo)
%   filtfun    - frequency response and roots (used by dfildemo)
%   filtfun2   - frequency response norm and roots (used by dfildemo)
%   fitfun     - return error norm in fitting data (used by datdemo)
%   fitfun2    - return vector of errors in fitting data (used by datdemo)
%
%   Semi-infinite Utility Routines
%   semifun    - translates semi-infinite problem to constrained problem
%   findmax    - interpolates the maxima in a vector of data 
%   findmax2   - interpolates the maxima in a matrix of data 
%   v2sort     - sorts two vectors and then removes missing elements
%
%   Goal-attainment Utility Routines
%   goalfun    - translates goal-attainment problem to constrained problem
%   goalgra    - translates gradient in goal-attainment problem
%
%   Test Routines
%   toptim     - optimization test-suite
%   toptimf    - test functions for optimization test-suite 
%   toptimg    - test function gradients for optimization test-suite 
%
%   Other
%   graderr    - used to check gradient discrepancy 
%   lsint      - function to initialize leastsq routine
%   optint     - function to initialize fminu routine
%   updhess    - performs the Inverse Hessian Update
%   searchq    - line search routine for fminu and leastsq functions

% Copyright (c) 1990-94 by The MathWorks, Inc.
% $Revision: 1.12 $  $Date: 1994/03/14 22:04:01 $
