% SIMULINK demonstrations and samples.
% Version 1.3c   15-August-94
%
% Main demonstration menu.
%   simdemo    - Main menu of SIMULINK demonstrations.
%
% Demonstration models.
%   vdp        - Van der Pol system of equations.
%   f14        - F-14 aircraft model.
%   thermo     - Thermodynamics of a house.
%   pops       - Population dynamics.
%   parmest    - Parameter estimation.
%   multi      - Multivariate lines.
%   steps      - Effects of varying step size.
%   rlsest     - Adaptive control.
%   penddemo   - Inverted pendulum (on cart) with animation.
%   filters    - Three different filters.
%
% Demonstration models for case studies #1,#2,#3 in the user's guide.
%   f14c       - F-14 benchmark, closed-loop form.
%   f14o       - F-14 benchmark, open-loop form.
%   f14n       - F-14 block diagram, alternate form.
%   ben2asys   - JHU/APL continuous benchmark, simple 13-state model
%   ben2bsys   - JHU/APL continuous benchmark, intermediate 42-state model.
%   ben2csys   - JHU/APL continuous benchmark, difficult 74-state model.
%   ben3asys   - JHU/APL sampled-data benchmark, simple 10-state model.
%   ben3bsys   - JHU/APL sampled-data benchmark, complex 29-state model.
%
% Demonstration scripts.
%   popdemo    - Population dynamics.
%   vdpdemo    - Van der Pol equation.
%
% Execute the MATLAB command "simdemo" to see a menu of all demos and
% models in this directory (except for case studies #1-3).  The demo menu
% is also available from inside the "Extras" block in the main
% SIMULINK block library (which is displayed by executing "simulink").

% The routines below this line are available through SIMDEMO and the
% demo menu in the Extras block of the main SIMULINK block library.
%
% Submenus for simdemo
%   lqgdemos   - Menu of LQG design demonstrations.
%   rctdm      - Menu of Robust Control Toolbox demonstrations.
%   musyndm    - Menu of Mu-synthesis Toolbox demonstrations.
%
% Demonstration models of specialized blocks.
%   sources    - Source blocks demonstration.
%   sinks      - Sink blocks demonstration.
%   discrete   - Discrete blocks demonstration.
%   linear     - Linear blocks demonstration.
%   nonlin     - Nonlinear blocks demonstration.
%   portdemo   - Connection blocks demonstration.
%   sumprod    - Signal addition and multiplication.
%   corrdemo   - Auto-correlator block.
%   fohdemo    - First order hold block.
%   lorenzs    - Lorenz attractor with X-Y scope.
%   lorenz2    - Lorenz attractor with storage scope.
%   memdemo    - Memory block.
%   psddemo    - Power spectral density block.
%   simident   - Autoregressive model estimator.
%   spectf     - Spectrum analyzer block.
%   tabdemo    - 2-D table lookup block.
%   tdeldemo   - Time delay and variable delay block.
%   bounce     - Bouncing ball using reset integrator.
%   logdemo    - Logic blocks.
%
% LQG demo (lqgdemos) support routines.
%   lqgdemos   - SIMULINK demos for LQG design.
%   lqgdata    - data for the LQG demos.
%   lqgdemo1   - LQG demo 1, full state feedback.
%   lqgdemo2   - LQG demo 2, steady-state Kalman estimator.
%   lqgdemo3   - LQG demo 3, noise input. 
%   lqgdemo4   - LQG demo 4, integral action for tracking.
%   lqgdemo5   - LQG demo 5, nonlinear plant.
%   lqgdemo6   - LQG demo 6, discrete-time controller.
%   lqgopt     - LQG design by optimization for nonlinear plant.
%   lqgoptm    - script file to perform optimization.
%   lqgcost    - LQG cost function for use with lqgoptm.
%
% Robust Control Toolbox demo (rctdm) support routines.
%   rctdm      - SIMULINK Robust Control Toolbox demos.
%   ltrdemo1   - LTR design demonstration 1, without model perturbation.
%   ltrdes1    - design m-file for ltrdemo1.
%   ltrdata1   - initial data file and help file for ltrdemo1.
%   ltrdemo2   - LTR design demonstration 2, with model perturbation.
%   ltrdes2    - design m-file for ltrdemo2.
%   ltrdata2   - initial data file and help file for ltrdemo2.
%   h2demo1    - H2 design demonstration.
%   h2des1     - design m-file for h2demo1.
%   h2data     - initial data file and help file for h2demo1.
%   hinfdm     - H_infinity design demonstration.
%   hinfdes1   - design m-file for hinfdemo.
%   hinfdata   - initial data file and help file for hinfdemo.
%
% Mu Analysis and Synthesis Toolbox demo (musyndm) support routines.
%   musyndm    - SIMULINK Mu-synthesis Toolbox demos.
%   musyndm1   - Mu-synthesis SISO demo 1 without system perturbation.
%   mudes1     - desgin m-file for mudemo1.
%   mudata1    - initial data file and help file for mudemo1.
%   musyndm2   - Mu-synthesis SISO demo 2 with system perturbation.
%   mudes2     - desgin m-file for mudemo2.
%   mudata2    - initial data file and help file for mudemo2.
%   musyndm3   - Mu-synthesis MIMO demo 3 with system perturbation.
%   mudes3     - desgin m-file for mudemo3.
%   mudata3    - initial data file and help file for mudemo3.
%   musynfiw   - modified musynfit for Mu-synthesis Toolbox demos.
%   fitmagw    - modified fitmag for Mu-synthesis Toolbox demos.
%
% Other support routines.
%   pend0      - Initializes animation.
%   pendsets   - Updates animation.
%   pendan     - S-function for animation.
%   pendan.c   - MEX-file version of pendan.
%   rlsppd     - rlsest discrete pole-placement utility.
%   rlspps     - rlsest continuous pole-placement utility.
%   rlsests    - rlsest S-function utility.
%
% Data files for various models and demos.
%   f14dat     - F-14 constant definitions.
%   f14def     - F-14 alternate constant definitions.
%   ben2adat   - Constant definitions for ben2asys.
%   ben2bdat   - Constant definitions for ben2bsys.
%   ben2cdat   - Constant definitions for ben2csys.
%   ben3adat   - Constant definitions for ben3asys.
%   ben3bdat   - Constant definitions for ben3bsys.
%   multidat   - Data for multi demo.

% Copyright (c) 1990-94 by The MathWorks, Inc.
