function [ret,x0,str,ts,xts]=ben3bsys(t,x,u,flag);
%BEN3BSYS	is the M-file description of the SIMULINK system named BEN3BSYS.
%	The block-diagram can be displayed by typing: BEN3BSYS.
%
%	SYS=BEN3BSYS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BEN3BSYS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BEN3BSYS with a FLAG of zero:
%	[SIZES]=BEN3BSYS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[29,94,728,377])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '4')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Load callback','ben3bdat');

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G13'])
set_param([sys,'/','G13'],...
		'orientation',2,...
		'Numerator','gn4',...
		'Denominator','gd4',...
		'Sample time','[T1,offT1]',...
		'position',[215,122,265,158])

add_block('built-in/Step Fcn',[sys,'/','Step'])
set_param([sys,'/','Step'],...
		'Time','0',...
		'position',[10,34,30,56])

add_block('built-in/Inport',[sys,'/','R'])
set_param([sys,'/','R'],...
		'position',[10,90,30,110])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'position',[80,40,100,60])

add_block('built-in/Transfer Fcn',[sys,'/','G1, G2'])
set_param([sys,'/','G1, G2'],...
		'Numerator','gn1_gn2',...
		'Denominator','gd1',...
		'position',[410,39,475,81])


%     Subsystem  'G10'.

new_system([sys,'/','G10'])
set_param([sys,'/','G10'],'Location',[100,100,300,300])

add_block('built-in/Transfer Fcn',[sys,'/','G10/G101'])
set_param([sys,'/','G10/G101'],...
		'orientation',2,...
		'Numerator','gn101',...
		'Denominator','gd101',...
		'position',[190,12,240,48])

add_block('built-in/Outport',[sys,'/','G10/Out_1'])
set_param([sys,'/','G10/Out_1'],...
		'orientation',2,...
		'position',[20,20,40,40])

add_block('built-in/Transfer Fcn',[sys,'/','G10/G102'])
set_param([sys,'/','G10/G102'],...
		'orientation',2,...
		'Numerator','gn102',...
		'Denominator','gd102',...
		'position',[85,12,135,48])

add_block('built-in/Inport',[sys,'/','G10/In_1'])
set_param([sys,'/','G10/In_1'],...
		'orientation',2,...
		'position',[285,20,305,40])
add_line([sys,'/','G10'],[280,30;245,30])
add_line([sys,'/','G10'],[185,30;140,30])
add_line([sys,'/','G10'],[80,30;45,30])


%     Finished composite block 'G10'.

set_param([sys,'/','G10'],...
		'orientation',2,...
		'position',[460,200,490,250])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G12'])
set_param([sys,'/','G12'],...
		'orientation',2,...
		'Numerator','gn12',...
		'Denominator','gd12',...
		'Sample time','[T3,offT3]',...
		'position',[370,207,420,243])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G5'])
set_param([sys,'/','G5'],...
		'orientation',2,...
		'Numerator','gn5',...
		'Denominator','gd5',...
		'Sample time','[T1,offT1]',...
		'position',[220,207,270,243])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','--',...
		'position',[190,43,205,67])

add_block('built-in/Note',[sys,'/','T1'])
set_param([sys,'/','T1'],...
		'position',[260,35,265,40])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[225,48,240,72])


%     Subsystem  'G6 G13'.

new_system([sys,'/','G6 G13'])
set_param([sys,'/','G6 G13'],'Location',[45,122,343,202])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G6 G13/G6'])
set_param([sys,'/','G6 G13/G6'],...
		'orientation',2,...
		'Numerator','gn6',...
		'Denominator','gd6',...
		'Sample time','[T2,offT2]',...
		'position',[90,12,140,48])


%     Subsystem  'G6 G13/G13'.

new_system([sys,'/','G6 G13/G13'])
set_param([sys,'/','G6 G13/G13'],'Location',[62,148,378,217])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G6 G13/G13/G132'])
set_param([sys,'/','G6 G13/G13/G132'],...
		'orientation',2,...
		'Numerator','gn132',...
		'Denominator','gd132',...
		'Sample time','[T2,offT2]',...
		'position',[85,12,135,48])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G6 G13/G13/G131'])
set_param([sys,'/','G6 G13/G13/G131'],...
		'orientation',2,...
		'Numerator','gn131',...
		'Denominator','gd131',...
		'Sample time','[T2,offT2]',...
		'position',[175,12,225,48])

add_block('built-in/Inport',[sys,'/','G6 G13/G13/In_1'])
set_param([sys,'/','G6 G13/G13/In_1'],...
		'orientation',2,...
		'position',[275,20,295,40])

add_block('built-in/Outport',[sys,'/','G6 G13/G13/Out_1'])
set_param([sys,'/','G6 G13/G13/Out_1'],...
		'orientation',2,...
		'position',[20,20,40,40])
add_line([sys,'/','G6 G13/G13'],[80,30;45,30])
add_line([sys,'/','G6 G13/G13'],[170,30;140,30])
add_line([sys,'/','G6 G13/G13'],[270,30;230,30])


%     Finished composite block 'G6 G13/G13'.

set_param([sys,'/','G6 G13/G13'],...
		'orientation',2,...
		'position',[190,5,220,55])

add_block('built-in/Outport',[sys,'/','G6 G13/Out_1'])
set_param([sys,'/','G6 G13/Out_1'],...
		'orientation',2,...
		'position',[20,20,40,40])

add_block('built-in/Inport',[sys,'/','G6 G13/In_1'])
set_param([sys,'/','G6 G13/In_1'],...
		'orientation',2,...
		'position',[265,20,285,40])
add_line([sys,'/','G6 G13'],[185,30;145,30])
add_line([sys,'/','G6 G13'],[85,30;45,30])
add_line([sys,'/','G6 G13'],[260,30;225,30])


%     Finished composite block 'G6 G13'.

set_param([sys,'/','G6 G13'],...
		'orientation',2,...
		'position',[305,115,335,165])


%     Subsystem  'G7 G14'.

new_system([sys,'/','G7 G14'])
set_param([sys,'/','G7 G14'],'Location',[33,119,333,211])


%     Subsystem  'G7 G14/G14'.

new_system([sys,'/','G7 G14/G14'])
set_param([sys,'/','G7 G14/G14'],'Location',[40,168,360,246])

add_block('built-in/Outport',[sys,'/','G7 G14/G14/Out_1'])
set_param([sys,'/','G7 G14/G14/Out_1'],...
		'orientation',2,...
		'position',[20,20,40,40])

add_block('built-in/Inport',[sys,'/','G7 G14/G14/In_1'])
set_param([sys,'/','G7 G14/G14/In_1'],...
		'orientation',2,...
		'position',[275,20,295,40])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G7 G14/G14/G131'])
set_param([sys,'/','G7 G14/G14/G131'],...
		'orientation',2,...
		'Numerator','gn131',...
		'Denominator','gd131',...
		'Sample time','[T2,offT2]',...
		'position',[175,12,225,48])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G7 G14/G14/G132'])
set_param([sys,'/','G7 G14/G14/G132'],...
		'orientation',2,...
		'Numerator','gn132',...
		'Denominator','gd132',...
		'Sample time','[T2,offT2]',...
		'position',[85,12,135,48])
add_line([sys,'/','G7 G14/G14'],[80,30;45,30])
add_line([sys,'/','G7 G14/G14'],[170,30;140,30])
add_line([sys,'/','G7 G14/G14'],[270,30;230,30])


%     Finished composite block 'G7 G14/G14'.

set_param([sys,'/','G7 G14/G14'],...
		'orientation',2,...
		'position',[190,5,220,55])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G7 G14/G7'])
set_param([sys,'/','G7 G14/G7'],...
		'orientation',2,...
		'Numerator','gn7',...
		'Denominator','gd7',...
		'Sample time','[T2,offT2]',...
		'position',[95,12,145,48])

add_block('built-in/Inport',[sys,'/','G7 G14/In_1'])
set_param([sys,'/','G7 G14/In_1'],...
		'orientation',2,...
		'position',[260,20,280,40])

add_block('built-in/Outport',[sys,'/','G7 G14/Out_1'])
set_param([sys,'/','G7 G14/Out_1'],...
		'orientation',2,...
		'position',[20,20,40,40])
add_line([sys,'/','G7 G14'],[185,30;150,30])
add_line([sys,'/','G7 G14'],[255,30;225,30])
add_line([sys,'/','G7 G14'],[90,30;45,30])


%     Finished composite block 'G7 G14'.

set_param([sys,'/','G7 G14'],...
		'orientation',2,...
		'position',[305,200,335,250])

add_block('built-in/Note',[sys,'/','T1 '])
set_param([sys,'/','T1 '],...
		'position',[285,195,290,200])

add_block('built-in/Note',[sys,'/',' T1 '])
set_param([sys,'/',' T1 '],...
		'position',[280,110,285,117])

add_block('built-in/Note',[sys,'/','T2 '])
set_param([sys,'/','T2 '],...
		'position',[350,110,355,117])

add_block('built-in/Note',[sys,'/','T2'])
set_param([sys,'/','T2'],...
		'position',[350,195,355,202])

add_block('built-in/Note',[sys,'/','T3'])
set_param([sys,'/','T3'],...
		'position',[435,190,440,197])


%     Subsystem  'G8'.

new_system([sys,'/','G8'])
set_param([sys,'/','G8'],'Location',[103,144,364,224])

add_block('built-in/Outport',[sys,'/','G8/Out_1'])
set_param([sys,'/','G8/Out_1'],...
		'position',[230,20,250,40])

add_block('built-in/Transfer Fcn',[sys,'/','G8/G82'])
set_param([sys,'/','G8/G82'],...
		'Numerator','gn82',...
		'Denominator','gd82',...
		'position',[150,12,200,48])

add_block('built-in/Transfer Fcn',[sys,'/','G8/G81'])
set_param([sys,'/','G8/G81'],...
		'Numerator','gn81',...
		'Denominator','gd81',...
		'position',[65,12,115,48])

add_block('built-in/Inport',[sys,'/','G8/In_1'])
set_param([sys,'/','G8/In_1'],...
		'position',[20,20,40,40])
add_line([sys,'/','G8'],[45,30;60,30])
add_line([sys,'/','G8'],[120,30;145,30])
add_line([sys,'/','G8'],[205,30;225,30])


%     Finished composite block 'G8'.

set_param([sys,'/','G8'],...
		'position',[355,35,385,85])


%     Subsystem  'G9'.

new_system([sys,'/','G9'])
set_param([sys,'/','G9'],'Location',[100,76,393,145])

add_block('built-in/Outport',[sys,'/','G9/Out_1'])
set_param([sys,'/','G9/Out_1'],...
		'orientation',2,...
		'position',[30,20,50,40])

add_block('built-in/Transfer Fcn',[sys,'/','G9/G92'])
set_param([sys,'/','G9/G92'],...
		'orientation',2,...
		'Numerator','gn92',...
		'Denominator','gd92',...
		'position',[90,12,140,48])

add_block('built-in/Inport',[sys,'/','G9/In_1'])
set_param([sys,'/','G9/In_1'],...
		'orientation',2,...
		'position',[255,20,275,40])

add_block('built-in/Transfer Fcn',[sys,'/','G9/G91'])
set_param([sys,'/','G9/G91'],...
		'orientation',2,...
		'Numerator','gn91',...
		'Denominator','gd91',...
		'position',[175,12,225,48])
add_line([sys,'/','G9'],[85,30;55,30])
add_line([sys,'/','G9'],[170,30;145,30])
add_line([sys,'/','G9'],[250,30;230,30])


%     Finished composite block 'G9'.

set_param([sys,'/','G9'],...
		'orientation',2,...
		'position',[445,115,475,165])


%     Subsystem  'G11'.

new_system([sys,'/','G11'])
set_param([sys,'/','G11'],'Location',[4,51,448,124])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G11/G113'])
set_param([sys,'/','G11/G113'],...
		'orientation',2,...
		'Numerator','gn113',...
		'Denominator','gd113',...
		'Sample time','[T4,offT4]',...
		'position',[95,12,145,48])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G11/G112'])
set_param([sys,'/','G11/G112'],...
		'orientation',2,...
		'Numerator','gn112',...
		'Denominator','gd112',...
		'Sample time','[T4,offT4]',...
		'position',[195,12,245,48])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G11/G111'])
set_param([sys,'/','G11/G111'],...
		'orientation',2,...
		'Numerator','gn111',...
		'Denominator','gd111',...
		'Sample time','[T4,offT4]',...
		'position',[305,12,355,48])

add_block('built-in/Outport',[sys,'/','G11/Out_1'])
set_param([sys,'/','G11/Out_1'],...
		'orientation',2,...
		'position',[20,20,40,40])

add_block('built-in/Inport',[sys,'/','G11/In_1'])
set_param([sys,'/','G11/In_1'],...
		'orientation',2,...
		'position',[415,20,435,40])
add_line([sys,'/','G11'],[90,30;45,30])
add_line([sys,'/','G11'],[190,30;150,30])
add_line([sys,'/','G11'],[300,30;250,30])
add_line([sys,'/','G11'],[410,30;360,30])


%     Finished composite block 'G11'.

set_param([sys,'/','G11'],...
		'orientation',2,...
		'position',[370,115,400,165])

add_block('built-in/Note',[sys,'/','T4'])
set_param([sys,'/','T4'],...
		'position',[420,110,425,117])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','G3'])
set_param([sys,'/','G3'],...
		'Numerator','gn3',...
		'Denominator','gd3',...
		'Sample time','[T1,offT1]',...
		'position',[120,32,170,68])

add_block('built-in/Demux',[sys,'/','Demux1'])
set_param([sys,'/','Demux1'],...
		'hide name',0,...
		'outputs','2',...
		'position',[495,38,540,82])

add_block('built-in/To Workspace',[sys,'/','C1 data'])
set_param([sys,'/','C1 data'],...
		'mat-name','C1_data',...
		'buffer','20000',...
		'position',[605,130,665,150])

add_block('built-in/Note',[sys,'/','T1  '])
set_param([sys,'/','T1  '],...
		'position',[110,10,115,28])

add_block('built-in/Scope',[sys,'/','C1'])
set_param([sys,'/','C1'],...
		'Vgain','2.000000',...
		'Hgain','4.100000',...
		'Vmax','4.000000',...
		'Hmax','8.200000',...
		'Window',[592,228,823,383],...
		'position',[610,30,645,70])

add_block('built-in/Outport',[sys,'/','C1(t)'])
set_param([sys,'/','C1(t)'],...
		'position',[620,200,640,220])

add_block('built-in/Zero-Order Hold',[sys,'/',['Zero-Order',13,'Hold']])
set_param([sys,'/',['Zero-Order',13,'Hold']],...
		'position',[285,44,320,76])
add_line(sys,[35,100;50,100;50,55;75,55])
add_line(sys,[35,45;75,45])
add_line(sys,[545,50;580,50;580,210;615,210])
add_line(sys,[545,50;580,50;580,140;480,140])
add_line(sys,[545,70;545,225;495,225])
add_line(sys,[545,50;605,50])
add_line(sys,[480,60;490,60])
add_line(sys,[390,60;405,60])
add_line(sys,[105,50;115,50])
add_line(sys,[175,50;185,50])
add_line(sys,[210,55;220,55])
add_line(sys,[210,140;207,140;207,65;220,65])
add_line(sys,[245,60;280,60])
add_line(sys,[325,60;350,60])
add_line(sys,[440,140;405,140])
add_line(sys,[365,140;340,140])
add_line(sys,[300,140;270,140])
add_line(sys,[455,225;425,225])
add_line(sys,[365,225;340,225])
add_line(sys,[300,225;275,225])
add_line(sys,[215,225;175,225;185,60])
add_line(sys,[580,140;600,140])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
