function [ret,x0,str]=f14n(t,x,u,flag);
%F14N	is the M-file description of the SIMULINK system named F14N.
%	The block-diagram can be displayed by typing: F14N.
%
%	SYS=F14N(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes F14N to return state derivitives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling F14N with a FLAG of zero:
%	[SIZES]=F14N([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

%	Copyright (c) 1990-94 by The MathWorks, Inc.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile: 
sys = mfilename;
new_system(sys)
simver(1.3)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[2,13,650,456])
     open_system(sys)
end;
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'2')
set_param(sys,'Min step size',	'1e-8')
set_param(sys,'Max step size',	'.01')
set_param(sys,'Relative error','1e-4')
set_param(sys,'Return vars',	'')

add_block('built-in/Inport',[sys,'/',['Noise',13,'Input']])
set_param([sys,'/',['Noise',13,'Input']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','3',...
		'position',[180,280,200,300])


%     Subsystem  ['Dryden Wind',13,'Gust Models'].

new_system([sys,'/',['Dryden Wind',13,'Gust Models']])
set_param([sys,'/',['Dryden Wind',13,'Gust Models']],'Location',[115,54,581,332])

add_block('built-in/Transfer Fcn',[sys,'/',['Dryden Wind',13,'Gust Models/Q-gust model']])
set_param([sys,'/',['Dryden Wind',13,'Gust Models/Q-gust model']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Numerator','pi/(4*b)*[1 0]',...
		'Denominator','[1 pi*Vto/(4*b)]',...
		'position',[150,160,290,210])

add_block('built-in/Outport',[sys,'/',['Dryden Wind',13,'Gust Models/wGust',13,'(ft//sec)']])
set_param([sys,'/',['Dryden Wind',13,'Gust Models/wGust',13,'(ft//sec)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[375,37,400,63])

add_block('built-in/Outport',[sys,'/',['Dryden Wind',13,'Gust Models/qGust',13,'(rad//sec)']])
set_param([sys,'/',['Dryden Wind',13,'Gust Models/qGust',13,'(rad//sec)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','2',...
		'position',[375,172,400,198])

add_block('built-in/Transfer Fcn',[sys,'/',['Dryden Wind',13,'Gust Models/W-gust model']])
set_param([sys,'/',['Dryden Wind',13,'Gust Models/W-gust model']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Numerator','Swg/sqrt(a^3)*[sqrt(3)*a,1]',...
		'Denominator','[1 (2/a) 1/a^2]',...
		'position',[110,22,330,78])

add_block('built-in/Inport',[sys,'/',['Dryden Wind',13,'Gust Models/Noise',13,'Input']])
set_param([sys,'/',['Dryden Wind',13,'Gust Models/Noise',13,'Input']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[35,37,60,63])
add_line([sys,'/',['Dryden Wind',13,'Gust Models']],[335,50;370,50])
add_line([sys,'/',['Dryden Wind',13,'Gust Models']],[350,50;350,115;115,115;115,185;145,185])
add_line([sys,'/',['Dryden Wind',13,'Gust Models']],[295,185;370,185])
add_line([sys,'/',['Dryden Wind',13,'Gust Models']],[65,50;105,50])


%     Finished composite block ['Dryden Wind',13,'Gust Models'].

set_param([sys,'/',['Dryden Wind',13,'Gust Models']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[240,262,270,313])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Mq',...
		'position',[360,305,400,345])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Mw',...
		'position',[360,253,400,297])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Zw',...
		'position',[360,206,400,244])


%     Subsystem  ['Command',13,'Generator'].

new_system([sys,'/',['Command',13,'Generator']])
set_param([sys,'/',['Command',13,'Generator']],'Location',[62,227,509,447])

add_block('built-in/Outport',[sys,'/',['Command',13,'Generator/alpha',13,'command']])
set_param([sys,'/',['Command',13,'Generator/alpha',13,'command']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[375,50,395,70])

add_block('built-in/Transfer Fcn',[sys,'/',['Command',13,'Generator/Slow Pole']])
set_param([sys,'/',['Command',13,'Generator/Slow Pole']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Numerator','[0.01]',...
		'Denominator','[ 1 0.01]',...
		'position',[170,22,250,78])

add_block('built-in/Constant',[sys,'/',['Command',13,'Generator/Constant']])
set_param([sys,'/',['Command',13,'Generator/Constant']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Value','1',...
		'position',[20,37,45,63])

add_block('built-in/Transfer Fcn',[sys,'/',['Command',13,'Generator/Fast Pole']])
set_param([sys,'/',['Command',13,'Generator/Fast Pole']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Numerator','[426.435]',...
		'Denominator','[ 1 426.435]',...
		'position',[170,96,250,154])

add_block('built-in/Sum',[sys,'/',['Command',13,'Generator/Sum1']])
set_param([sys,'/',['Command',13,'Generator/Sum1']],...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','-+',...
		'position',[295,40,320,75])

add_block('built-in/Gain',[sys,'/',['Command',13,'Generator/Gain1']])
set_param([sys,'/',['Command',13,'Generator/Gain1']],...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','0.0349',...
		'position',[65,21,120,79])

add_block('built-in/Note',[sys,'/',['Command',13,'Generator/Second Order Command Generator Model']])
set_param([sys,'/',['Command',13,'Generator/Second Order Command Generator Model']],...
		'Font Number',720897,...
		'Drop Shadow',720896,...
		'position',[210,180,211,181])
add_line([sys,'/',['Command',13,'Generator']],[325,60;370,60])
add_line([sys,'/',['Command',13,'Generator']],[255,50;290,50])
add_line([sys,'/',['Command',13,'Generator']],[255,125;265,125;265,65;290,65])
add_line([sys,'/',['Command',13,'Generator']],[50,50;60,50])
add_line([sys,'/',['Command',13,'Generator']],[125,50;165,50])
add_line([sys,'/',['Command',13,'Generator']],[140,50;140,125;165,125])


%     Finished composite block ['Command',13,'Generator'].

set_param([sys,'/',['Command',13,'Generator']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[35,25,65,75])

add_block('built-in/Outport',[sys,'/','Nz Pilot (g)'])
set_param([sys,'/','Nz Pilot (g)'],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','4',...
		'position',[740,120,760,140])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',1,...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','++',...
		'position',[85,95,120,115])

add_block('built-in/Outport',[sys,'/','alpha (rad)'])
set_param([sys,'/','alpha (rad)'],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[755,200,775,220])

add_block('built-in/Inport',[sys,'/',['alpha',13,'command']])
set_param([sys,'/',['alpha',13,'command']],...
		'orientation',2,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[140,40,160,60])

add_block('built-in/Note',[sys,'/','w'])
set_param([sys,'/','w'],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[645,195,646,196])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','1/Uo',...
		'position',[655,186,705,234])


%     Subsystem  ['Nz pilot',13,'calculation'].

new_system([sys,'/',['Nz pilot',13,'calculation']])
set_param([sys,'/',['Nz pilot',13,'calculation']],'Location',[50,50,587,397])

add_block('built-in/Outport',[sys,'/',['Nz pilot',13,'calculation/Pilot',13,'g force (g)']])
set_param([sys,'/',['Nz pilot',13,'calculation/Pilot',13,'g force (g)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[470,115,490,135])

add_block('built-in/Sum',[sys,'/',['Nz pilot',13,'calculation/Sum1']])
set_param([sys,'/',['Nz pilot',13,'calculation/Sum1']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','-++',...
		'position',[340,95,360,155])

add_block('built-in/Inport',[sys,'/',['Nz pilot',13,'calculation/wDot']])
set_param([sys,'/',['Nz pilot',13,'calculation/wDot']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[25,35,45,55])

add_block('built-in/Product',[sys,'/',['Nz pilot',13,'calculation/Product']])
set_param([sys,'/',['Nz pilot',13,'calculation/Product']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','2',...
		'position',[160,242,185,273])

add_block('built-in/Note',[sys,'/',['Nz pilot',13,'calculation/Nz pilot calculation']])
set_param([sys,'/',['Nz pilot',13,'calculation/Nz pilot calculation']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[369,270,370,271])

add_block('built-in/Inport',[sys,'/',['Nz pilot',13,'calculation/qDot']])
set_param([sys,'/',['Nz pilot',13,'calculation/qDot']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','2',...
		'position',[25,115,45,135])

add_block('built-in/Gain',[sys,'/',['Nz pilot',13,'calculation/Gain2']])
set_param([sys,'/',['Nz pilot',13,'calculation/Gain2']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','1/32.2',...
		'position',[390,102,440,148])

add_block('built-in/Gain',[sys,'/',['Nz pilot',13,'calculation/Gain1']])
set_param([sys,'/',['Nz pilot',13,'calculation/Gain1']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','22.8',...
		'position',[215,102,265,148])

add_block('built-in/Constant',[sys,'/',['Nz pilot',13,'calculation/Constant']])
set_param([sys,'/',['Nz pilot',13,'calculation/Constant']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Value','Uo',...
		'position',[25,252,50,278])

add_block('built-in/Note',[sys,'/',['Nz pilot',13,'calculation/Nz = (dq//dt*22.8 + q*Uo - dw//dt)//g']])
set_param([sys,'/',['Nz pilot',13,'calculation/Nz = (dq//dt*22.8 + q*Uo - dw//dt)//g']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[368,295,369,296])

add_block('built-in/Inport',[sys,'/',['Nz pilot',13,'calculation/q']])
set_param([sys,'/',['Nz pilot',13,'calculation/q']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','3',...
		'position',[25,190,45,210])
add_line([sys,'/',['Nz pilot',13,'calculation']],[190,260;290,260;290,145;335,145])
add_line([sys,'/',['Nz pilot',13,'calculation']],[270,125;335,125])
add_line([sys,'/',['Nz pilot',13,'calculation']],[50,45;290,45;290,105;335,105])
add_line([sys,'/',['Nz pilot',13,'calculation']],[365,125;385,125])
add_line([sys,'/',['Nz pilot',13,'calculation']],[445,125;465,125])
add_line([sys,'/',['Nz pilot',13,'calculation']],[55,265;155,265])
add_line([sys,'/',['Nz pilot',13,'calculation']],[50,125;210,125])
add_line([sys,'/',['Nz pilot',13,'calculation']],[50,200;105,200;105,250;155,250])


%     Finished composite block ['Nz pilot',13,'calculation'].

set_param([sys,'/',['Nz pilot',13,'calculation']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[655,32,690,88])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[310,42,335,68])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','++',...
		'position',[450,280,470,320])

add_block('built-in/Note',[sys,'/','q'])
set_param([sys,'/','q'],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'position',[640,250,641,251])


%     Subsystem  ['Aircraft Dynamics',13,'Model'].

new_system([sys,'/',['Aircraft Dynamics',13,'Model']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model']],'Location',[41,8,640,480])

add_block('built-in/Integrator',[sys,'/',['Aircraft Dynamics',13,'Model/Integrator1']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Integrator1']],...
		'Font Number',720897,...
		'Drop Shadow',720896,...
		'Initial','0',...
		'position',[425,315,445,335])

add_block('built-in/Sum',[sys,'/',['Aircraft Dynamics',13,'Model/Sum3']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Sum3']],...
		'Font Number',720897,...
		'Drop Shadow',720896,...
		'inputs','++',...
		'position',[360,315,380,335])

add_block('built-in/Gain',[sys,'/',['Aircraft Dynamics',13,'Model/Gain8']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Gain8']],...
		'orientation',2,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Zw',...
		'position',[380,360,420,400])

add_block('built-in/Gain',[sys,'/',['Aircraft Dynamics',13,'Model/Gain7']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Gain7']],...
		'orientation',2,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Zw',...
		'position',[355,20,395,60])

add_block('built-in/Sum',[sys,'/',['Aircraft Dynamics',13,'Model/Sum']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Sum']],...
		'Font Number',720897,...
		'Drop Shadow',720896,...
		'inputs','++',...
		'position',[330,95,350,115])

add_block('built-in/Integrator',[sys,'/',['Aircraft Dynamics',13,'Model/Integrator']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Integrator']],...
		'Font Number',720897,...
		'Drop Shadow',720896,...
		'Initial','0',...
		'position',[405,95,425,115])

add_block('built-in/Inport',[sys,'/',['Aircraft Dynamics',13,'Model/Rotary Gust',13,'qGust (rad//sec)']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Rotary Gust',13,'qGust (rad//sec)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','3',...
		'position',[160,308,185,332])

add_block('built-in/Inport',[sys,'/',['Aircraft Dynamics',13,'Model/Elevator',13,'Deflection',13,'d (deg)']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Elevator',13,'Deflection',13,'d (deg)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[35,23,60,47])

add_block('built-in/Gain',[sys,'/',['Aircraft Dynamics',13,'Model/Gain3']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Gain3']],...
		'orientation',2,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Uo',...
		'position',[280,175,320,215])

add_block('built-in/Gain',[sys,'/',['Aircraft Dynamics',13,'Model/Gain4']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Gain4']],...
		'orientation',2,...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Mw',...
		'position',[295,233,335,277])

add_block('built-in/Inport',[sys,'/',['Aircraft Dynamics',13,'Model/Vertical Gust',13,'wGust (ft//sec)']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Vertical Gust',13,'wGust (ft//sec)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','2',...
		'position',[155,98,180,122])

add_block('built-in/Outport',[sys,'/',['Aircraft Dynamics',13,'Model/Vertical Velocity',13,'w (ft//sec)']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Vertical Velocity',13,'w (ft//sec)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','1',...
		'position',[510,96,530,114])

add_block('built-in/Outport',[sys,'/',['Aircraft Dynamics',13,'Model/Pitch Rate',13,'q (rad//sec)']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Pitch Rate',13,'q (rad//sec)']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','2',...
		'position',[515,316,535,334])

add_block('built-in/Sum',[sys,'/',['Aircraft Dynamics',13,'Model/Sum1']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Sum1']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','+-+',...
		'position',[270,86,290,134])

add_block('built-in/Sum',[sys,'/',['Aircraft Dynamics',13,'Model/Sum2']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Sum2']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'inputs','+-+',...
		'position',[270,296,290,344])

add_block('built-in/Gain',[sys,'/',['Aircraft Dynamics',13,'Model/Gain5']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Gain5']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Zd',...
		'position',[130,15,165,55])

add_block('built-in/Gain',[sys,'/',['Aircraft Dynamics',13,'Model/Gain6']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Gain6']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Gain','Md',...
		'position',[130,365,165,405])

add_block('built-in/Note',[sys,'/',['Aircraft Dynamics',13,'Model/Aircraft Dynamics']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/Aircraft Dynamics']],...
		'Font Number',720897,...
		'Drop Shadow',720896,...
		'position',[245,400,246,401])

add_block('built-in/Outport',[sys,'/',['Aircraft Dynamics',13,'Model/wDot']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/wDot']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','3',...
		'position',[510,156,530,174])

add_block('built-in/Outport',[sys,'/',['Aircraft Dynamics',13,'Model/qDot']])
set_param([sys,'/',['Aircraft Dynamics',13,'Model/qDot']],...
		'Font Number',720899,...
		'Drop Shadow',720896,...
		'Port','4',...
		'position',[510,276,530,294])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[375,380;325,380;325,330;355,330])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[450,325;510,325])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[475,325;475,380;425,380])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[350,40;310,40;310,100;325,100])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[430,105;505,105])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[440,105;440,40;400,40])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[295,110;325,110])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[65,35;125,35])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[90,35;90,385;125,385])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[185,110;265,110])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[290,255;235,255;235,305;265,305])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[295,320;355,320])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[190,320;265,320])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[275,195;235,195;235,125;265,125])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[170,35;235,35;235,95;265,95])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[170,385;235,385;235,335;265,335])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[465,325;465,255;435,195;325,195])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[465,105;465,190;430,255;340,255])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[355,105;400,105])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[375,105;375,165;505,165])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[385,325;420,325])
add_line([sys,'/',['Aircraft Dynamics',13,'Model']],[400,325;400,285;505,285])


%     Finished composite block ['Aircraft Dynamics',13,'Model'].

set_param([sys,'/',['Aircraft Dynamics',13,'Model']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'position',[530,200,560,250])

add_block('built-in/Transfer Fcn',[sys,'/',['Actuator',13,'Model']])
set_param([sys,'/',['Actuator',13,'Model']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Numerator','[1]',...
		'Denominator','[ Ta, 1]',...
		'position',[285,117,345,163])


%     Subsystem  'Controller'.

new_system([sys,'/','Controller'])
set_param([sys,'/','Controller'],'Location',[47,71,658,481])

add_block('built-in/Inport',[sys,'/',['Controller/Open Loop',13,'Input']])
set_param([sys,'/',['Controller/Open Loop',13,'Input']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','4',...
		'position',[35,22,60,48])

add_block('built-in/Transfer Fcn',[sys,'/',['Controller/Alpha-sensor',13,'Low-pass Filter']])
set_param([sys,'/',['Controller/Alpha-sensor',13,'Low-pass Filter']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Numerator','[1]',...
		'Denominator','[Tal,1]',...
		'position',[95,225,170,275])

add_block('built-in/Note',[sys,'/','Controller/Controller'])
set_param([sys,'/','Controller/Controller'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'position',[435,300,436,301])

add_block('built-in/Inport',[sys,'/','Controller/alpha (rad)'])
set_param([sys,'/','Controller/alpha (rad)'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','2',...
		'position',[30,237,55,263])

add_block('built-in/Gain',[sys,'/','Controller/Gain3'])
set_param([sys,'/','Controller/Gain3'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Gain','Ka',...
		'position',[205,230,245,270])

add_block('built-in/Transfer Fcn',[sys,'/',['Controller/Pitch Rate',13,'Lead Filter']])
set_param([sys,'/',['Controller/Pitch Rate',13,'Lead Filter']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Numerator','[1,W1]',...
		'Denominator','[1,W2]',...
		'position',[95,315,165,365])

add_block('built-in/Inport',[sys,'/','Controller/q (rad//sec)'])
set_param([sys,'/','Controller/q (rad//sec)'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','3',...
		'position',[30,327,55,353])

add_block('built-in/Gain',[sys,'/','Controller/Gain2'])
set_param([sys,'/','Controller/Gain2'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Gain','Kq',...
		'position',[205,320,245,360])

add_block('built-in/Sum',[sys,'/','Controller/Sum1'])
set_param([sys,'/','Controller/Sum1'],...
		'orientation',3,...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'inputs','2',...
		'position',[257,190,293,210])

add_block('built-in/Transfer Fcn',[sys,'/',['Controller/Proportional',13,'plus integral',13,'compensator']])
set_param([sys,'/',['Controller/Proportional',13,'plus integral',13,'compensator']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Numerator','[Ki]',...
		'Denominator','[1,0]',...
		'position',[385,85,440,125])

add_block('built-in/Sum',[sys,'/','Controller/Sum2'])
set_param([sys,'/','Controller/Sum2'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'inputs','++-',...
		'position',[315,85,340,125])

add_block('built-in/Outport',[sys,'/',['Controller/Elevator',13,'Command (deg)']])
set_param([sys,'/',['Controller/Elevator',13,'Command (deg)']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','1',...
		'position',[540,82,565,108])

add_block('built-in/Inport',[sys,'/',['Controller/Stick',13,'Input (in)']])
set_param([sys,'/',['Controller/Stick',13,'Input (in)']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','1',...
		'position',[35,92,60,118])

add_block('built-in/Sum',[sys,'/','Controller/Sum'])
set_param([sys,'/','Controller/Sum'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'inputs','2',...
		'position',[475,75,500,115])

add_block('built-in/Transfer Fcn',[sys,'/',['Controller/Stick',13,'Prefilter']])
set_param([sys,'/',['Controller/Stick',13,'Prefilter']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Numerator','[1]',...
		'Denominator','[Ts,1]',...
		'position',[100,80,170,130])

add_block('built-in/Gain',[sys,'/','Controller/Gain'])
set_param([sys,'/','Controller/Gain'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Gain','Kf',...
		'position',[390,15,430,55])

add_block('built-in/Outport',[sys,'/',['Controller/Open Loop',13,'Output']])
set_param([sys,'/',['Controller/Open Loop',13,'Output']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','2',...
		'position',[545,217,570,243])
add_line([sys,'/','Controller'],[65,35;275,35;275,90;310,90])
add_line([sys,'/','Controller'],[175,105;310,105])
add_line([sys,'/','Controller'],[250,340;285,340;285,215])
add_line([sys,'/','Controller'],[250,250;265,250;265,215])
add_line([sys,'/','Controller'],[60,250;90,250])
add_line([sys,'/','Controller'],[175,250;200,250])
add_line([sys,'/','Controller'],[60,340;90,340])
add_line([sys,'/','Controller'],[170,340;200,340])
add_line([sys,'/','Controller'],[505,95;535,95])
add_line([sys,'/','Controller'],[65,105;95,105])
add_line([sys,'/','Controller'],[445,105;470,105])
add_line([sys,'/','Controller'],[435,35;455,35;455,85;470,85])
add_line([sys,'/','Controller'],[345,105;380,105])
add_line([sys,'/','Controller'],[360,105;360,35;385,35])
add_line([sys,'/','Controller'],[275,185;275,160;350,160;350,230;540,230])
add_line([sys,'/','Controller'],[275,160;275,120;310,120])


%     Finished composite block 'Controller'.

set_param([sys,'/','Controller'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'position',[150,125,180,175])

add_block('built-in/Note',[sys,'/','wGust'])
set_param([sys,'/','wGust'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'position',[296,255,297,256])

add_block('built-in/Note',[sys,'/','qGust'])
set_param([sys,'/','qGust'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'position',[295,280,296,281])

add_block('built-in/Transfer Fcn',[sys,'/',['Alpha-sensor',13,'error model']])
set_param([sys,'/',['Alpha-sensor',13,'error model']],...
		'orientation',2,...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Numerator','[Sa*sqrt(2*Wa)]',...
		'Denominator','[1 Wa]',...
		'position',[250,389,350,441])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'orientation',2,...
		'hide name',0,...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'inputs','++',...
		'position',[155,385,175,425])

add_block('built-in/Inport',[sys,'/',['Open Loop',13,'Input']])
set_param([sys,'/',['Open Loop',13,'Input']],...
		'orientation',2,...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','2',...
		'position',[150,210,170,230])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'orientation',2,...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Value','0',...
		'position',[405,402,430,428])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'mat-name','Nzp',...
		'buffer','1000',...
		'position',[730,47,775,73])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'mat-name','q',...
		'buffer','1000',...
		'position',[760,288,800,312])

add_block('built-in/Outport',[sys,'/','q (rad//sec)'])
set_param([sys,'/','q (rad//sec)'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','2',...
		'position',[775,345,795,365])

add_block('built-in/Outport',[sys,'/',['Open Loop',13,'Output']])
set_param([sys,'/',['Open Loop',13,'Output']],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'Port','3',...
		'position',[230,185,250,205])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'Font Number',655363,...
		'Drop Shadow',655360,...
		'mat-name','t',...
		'buffer','1000',...
		'position',[370,42,415,68])
add_line(sys,[695,60;725,60])
add_line(sys,[705,60;705,130;735,130])
add_line(sys,[135,50;110,50;110,90])
add_line(sys,[350,140;510,140;510,210;525,210])
add_line(sys,[405,225;525,225])
add_line(sys,[275,300;320,300;320,325;355,325])
add_line(sys,[405,275;425,275;425,290;445,290])
add_line(sys,[405,325;425,325;425,310;445,310])
add_line(sys,[185,140;280,140])
add_line(sys,[475,300;490,300;490,240;525,240])
add_line(sys,[275,275;355,275])
add_line(sys,[320,275;320,225;355,225])
add_line(sys,[565,210;650,210])
add_line(sys,[105,120;105,135;145,135])
add_line(sys,[245,415;180,415])
add_line(sys,[150,405;85,405;85,145;145,145])
add_line(sys,[710,210;750,210])
add_line(sys,[720,210;720,375;225,375;225,395;180,395])
add_line(sys,[145,220;125,220;125,165;145,165])
add_line(sys,[205,290;235,290])
add_line(sys,[400,415;355,415])
add_line(sys,[565,220;630,220;630,360;105,360;105,155;145,155])
add_line(sys,[630,300;755,300])
add_line(sys,[740,300;740,355;770,355])
add_line(sys,[185,165;215,165;215,195;225,195])
add_line(sys,[70,50;95,50;95,90])
add_line(sys,[340,55;365,55])
add_line(sys,[630,220;630,80;650,80])
add_line(sys,[565,230;580,230;580,40;650,40])
add_line(sys,[565,240;605,240;605,60;650,60])
% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,xstr]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
