function [ret,x0,str]=hinfdm(t,x,u,flag);
%HINFDM	is the M-file description of the SIMULINK system named HINFDM.
%	The block-diagram can be displayed by typing: HINFDM.
%
%	SYS=HINFDM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes HINFDM to return state derivitives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling HINFDM with a FLAG of zero:
%	[SIZES]=HINFDM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

%	Copyright (c) 1990-94 by The MathWorks, Inc.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile: 
sys = mfilename;
new_system(sys)
simver(1.3)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[109,118,724,484])
     open_system(sys)
end;
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'2000')
set_param(sys,'Min step size',	'0.01')
set_param(sys,'Max step size',	'0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Outport',[sys,'/','Outport4'])
set_param([sys,'/','Outport4'],...
		'Port','3',...
		'position',[560,215,580,235])

add_block('built-in/Note',[sys,'/','H_infinity Controller Design'])
set_param([sys,'/','H_infinity Controller Design'],...
		'position',[249,200,250,201])


%     Subsystem  'More Info'.

new_system([sys,'/','More Info'])
set_param([sys,'/','More Info'],'Location',[15,105,404,220])

add_block('built-in/Note',[sys,'/',['More Info/The original open-loop plant is an unstable system. Compare',13,'regular LQG desgin to see the difference.']])
set_param([sys,'/',['More Info/The original open-loop plant is an unstable system. Compare',13,'regular LQG desgin to see the difference.']],...
		'position',[191,75,192,76])

add_block('built-in/Note',[sys,'/',['More Info/This demonstration shows LQG//LTR controller design method.',13,'Robust control tool box is used in the design']])
set_param([sys,'/',['More Info/This demonstration shows LQG//LTR controller design method.',13,'Robust control tool box is used in the design']],...
		'position',[192,25,193,26])
set_param([sys,'/','More Info'],...
		'Mask Display','?')


%     Finished composite block 'More Info'.

set_param([sys,'/','More Info'],...
		'BackGround',5,...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[810,440,837,465])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','++-',...
		'position',[115,132,135,178])

add_block('built-in/Inport',[sys,'/','Inport'])
set_param([sys,'/','Inport'],...
		'position',[45,85,65,105])

add_block('built-in/Signal Generator',[sys,'/','Signal Gen.'])
set_param([sys,'/','Signal Gen.'],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','1.000000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[35,138,75,172])

add_block('built-in/State-space',[sys,'/','Controller1'])
set_param([sys,'/','Controller1'],...
		'A','ae',...
		'B','be',...
		'C','ce',...
		'D','de',...
		'Mask Display','H_infty Controller',...
		'Mask Type','H_infty CONTROLLER')
set_param([sys,'/','Controller1'],...
		'Mask Dialogue','H_infty controller.\n(Requires Control Toolbox and RCT)|Controller Matrix A:|Controller Matrix B:|Controller Matrix C:|Controller Matrix D:')
set_param([sys,'/','Controller1'],...
		'Mask Translate','ae=@1; be=@2; ce=@3; de=@4;',...
		'Mask Help','H_infty controller design. Mask and unmask this block to see how it works.',...
		'Mask Entries','ae\/be\/ce\/de\/')
set_param([sys,'/','Controller1'],...
		'position',[180,128,295,182])

add_block('built-in/Outport',[sys,'/','Outport1'])
set_param([sys,'/','Outport1'],...
		'position',[555,35,575,55])

add_block('built-in/Outport',[sys,'/','Outport2'])
set_param([sys,'/','Outport2'],...
		'Port','2',...
		'position',[550,80,570,100])

add_block('built-in/Outport',[sys,'/','Outport3'])
set_param([sys,'/','Outport3'],...
		'Port','4',...
		'position',[555,130,575,150])


%     Subsystem  'Plant'.

new_system([sys,'/','Plant'])
set_param([sys,'/','Plant'],'Location',[542,610,951,805])

add_block('built-in/Outport',[sys,'/','Plant/out'])
set_param([sys,'/','Plant/out'],...
		'position',[365,45,385,65])

add_block('built-in/Sum',[sys,'/','Plant/Sum1'])
set_param([sys,'/','Plant/Sum1'],...
		'inputs','+++',...
		'position',[325,37,345,73])

add_block('built-in/Product',[sys,'/','Plant/Product'])
set_param([sys,'/','Plant/Product'],...
		'position',[255,95,280,115])

add_block('built-in/State-space',[sys,'/','Plant/State-space'])
set_param([sys,'/','Plant/State-space'],...
		'A','a',...
		'B','b',...
		'C','c',...
		'D','d',...
		'position',[160,30,220,60])

add_block('built-in/Inport',[sys,'/','Plant/in'])
set_param([sys,'/','Plant/in'],...
		'position',[65,35,85,55])


%     Subsystem  ['Plant/Multiplicative',13,'noise'].

new_system([sys,'/',['Plant/Multiplicative',13,'noise']])
set_param([sys,'/',['Plant/Multiplicative',13,'noise']],'Location',[0,0,262,236])

add_block('built-in/Outport',[sys,'/',['Plant/Multiplicative',13,'noise/out_1']])
set_param([sys,'/',['Plant/Multiplicative',13,'noise/out_1']],...
		'position',[235,70,255,90])

add_block('built-in/White Noise',[sys,'/',['Plant/Multiplicative',13,'noise/White Noise']])
set_param([sys,'/',['Plant/Multiplicative',13,'noise/White Noise']],...
		'Seed','seed',...
		'position',[55,70,75,90])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Plant/Multiplicative',13,'noise/Zero Order Hold']])
set_param([sys,'/',['Plant/Multiplicative',13,'noise/Zero Order Hold']],...
		'Numerator','[sqrt(Cov)]',...
		'Denominator','[sqrt(Ts)]',...
		'Sample time','Ts',...
		'position',[140,61,205,99])
add_line([sys,'/',['Plant/Multiplicative',13,'noise']],[210,80;225,80])
add_line([sys,'/',['Plant/Multiplicative',13,'noise']],[80,80;130,80])
set_param([sys,'/',['Plant/Multiplicative',13,'noise']],...
		'Mask Display','plot(1:20,rand(1,20))',...
		'Mask Type','Input Noise')
set_param([sys,'/',['Plant/Multiplicative',13,'noise']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Variance:|Sample Time:|Seed')
set_param([sys,'/',['Plant/Multiplicative',13,'noise']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12)-0.5; ')
set_param([sys,'/',['Plant/Multiplicative',13,'noise']],...
		'Mask Help','Implemented using white noise into Zero Order Hold block. For faster simulation set sample time to highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Plant/Multiplicative',13,'noise']],...
		'Mask Entries','0.1\/1\/6455\/')


%     Finished composite block ['Plant/Multiplicative',13,'noise'].

set_param([sys,'/',['Plant/Multiplicative',13,'noise']],...
		'position',[85,74,125,106])


%     Subsystem  ['Plant/Additive',13,'noise'].

new_system([sys,'/',['Plant/Additive',13,'noise']])
set_param([sys,'/',['Plant/Additive',13,'noise']],'Location',[0,0,262,236])

add_block('built-in/Outport',[sys,'/',['Plant/Additive',13,'noise/out_1']])
set_param([sys,'/',['Plant/Additive',13,'noise/out_1']],...
		'position',[235,70,255,90])

add_block('built-in/White Noise',[sys,'/',['Plant/Additive',13,'noise/White Noise']])
set_param([sys,'/',['Plant/Additive',13,'noise/White Noise']],...
		'Seed','seed',...
		'position',[55,70,75,90])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Plant/Additive',13,'noise/Zero Order Hold']])
set_param([sys,'/',['Plant/Additive',13,'noise/Zero Order Hold']],...
		'Numerator','[sqrt(Cov)]',...
		'Denominator','[sqrt(Ts)]',...
		'Sample time','Ts',...
		'position',[140,61,205,99])
add_line([sys,'/',['Plant/Additive',13,'noise']],[210,80;225,80])
add_line([sys,'/',['Plant/Additive',13,'noise']],[80,80;130,80])
set_param([sys,'/',['Plant/Additive',13,'noise']],...
		'Mask Display','plot(1:20,rand(1,20))',...
		'Mask Type','Input Noise')
set_param([sys,'/',['Plant/Additive',13,'noise']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Variance:|Sample Time:|Seed')
set_param([sys,'/',['Plant/Additive',13,'noise']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12)-0.5; ')
set_param([sys,'/',['Plant/Additive',13,'noise']],...
		'Mask Help','Implemented using white noise into Zero Order Hold block. For faster simulation set sample time to highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Plant/Additive',13,'noise']],...
		'Mask Entries','0.1\/1\/12345\/')


%     Finished composite block ['Plant/Additive',13,'noise'].

set_param([sys,'/',['Plant/Additive',13,'noise']],...
		'position',[150,129,195,161])
add_line([sys,'/','Plant'],[200,145;305,145;305,65;315,65])
add_line([sys,'/','Plant'],[285,105;295,105;295,55;315,55])
add_line([sys,'/','Plant'],[225,45;240,45;240,100;245,100])
add_line([sys,'/','Plant'],[130,90;195,90;195,110;245,110])
add_line([sys,'/','Plant'],[225,45;315,45])
add_line([sys,'/','Plant'],[350,55;355,55])
add_line([sys,'/','Plant'],[90,45;150,45])


%     Finished composite block 'Plant'.

set_param([sys,'/','Plant'],...
		'position',[345,128,375,182])


%     Subsystem  ['About the musyn',13,'demo1'].

new_system([sys,'/',['About the musyn',13,'demo1']])
set_param([sys,'/',['About the musyn',13,'demo1']],'Location',[2,439,106,512])
set_param([sys,'/',['About the musyn',13,'demo1']],...
		'Mask Display','?',...
		'Mask Type','',...
		'Mask Dialogue','eval(''clc; more(24); help hinfdata; more off'')',...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['About the musyn',13,'demo1'].

set_param([sys,'/',['About the musyn',13,'demo1']],...
		'hide name',0,...
		'Drop Shadow',4,...
		'position',[543,287,576,318])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','3.000000',...
		'Hgain','10.000000',...
		'Vmax','3.000000',...
		'Hmax','20.000000',...
		'Window',[0,0,453,204],...
		'position',[550,172,570,198])

add_block('built-in/Transfer Fcn',[sys,'/',['Performance Weighting ',13,'Inv(W1) function']])
set_param([sys,'/',['Performance Weighting ',13,'Inv(W1) function']],...
		'Numerator','num1',...
		'Denominator','den1',...
		'Mask Display','plot(log10(w1),log10(ma1));',...
		'Mask Type','polynomial: num/den')
set_param([sys,'/',['Performance Weighting ',13,'Inv(W1) function']],...
		'Mask Dialogue','Transfer function\n numerator and denominator|numerator:|denominator:',...
		'Mask Translate','num1=@1;den1=@2;[ma1,ph1,w1]=bode(num1,den1);')
set_param([sys,'/',['Performance Weighting ',13,'Inv(W1) function']],...
		'Mask Help','Transfer function ',...
		'Mask Entries','num1\/den1\/',...
		'position',[200,22,300,68])

add_block('built-in/Transfer Fcn',[sys,'/',['Input Weighting',13,'W2 Function']])
set_param([sys,'/',['Input Weighting',13,'W2 Function']],...
		'Numerator','num2',...
		'Denominator','den2',...
		'Mask Display','plot(log10(w2),log10(ma2));',...
		'Mask Type','polynomial: num/den')
set_param([sys,'/',['Input Weighting',13,'W2 Function']],...
		'Mask Dialogue','Transfer Function\nnumerator and denominator:|numerator:|denominator:',...
		'Mask Translate','num2=@1;den2=@2;[ma2,pa2,w2]=bode(num2,den2);')
set_param([sys,'/',['Input Weighting',13,'W2 Function']],...
		'Mask Help','Transfer Function',...
		'Mask Entries','num2\/den2\/',...
		'position',[365,66,470,114])

add_block('built-in/Transfer Fcn',[sys,'/',['Robustness Weighting',13,'Inv(W3) function']])
set_param([sys,'/',['Robustness Weighting',13,'Inv(W3) function']],...
		'Numerator','num3',...
		'Denominator','den3',...
		'Mask Display','plot(log10(w3),log10(ma3))',...
		'Mask Type','polynomial: num/den')
set_param([sys,'/',['Robustness Weighting',13,'Inv(W3) function']],...
		'Mask Dialogue','Transfer Function\nnumerator and denominator:|numerator:|denominator:',...
		'Mask Translate','num3=@1;den3=@2;[ma3,ph3,w3]=bode(num3,den3);')
set_param([sys,'/',['Robustness Weighting',13,'Inv(W3) function']],...
		'Mask Help','Transfer Function',...
		'Mask Entries','num3\/den3\/',...
		'position',[430,201,535,249])


%     Subsystem  ['Double click here',13,'to show bode plot ',13,'of controller'].

new_system([sys,'/',['Double click here',13,'to show bode plot ',13,'of controller']])
set_param([sys,'/',['Double click here',13,'to show bode plot ',13,'of controller']],'Location',[2,439,106,512])
set_param([sys,'/',['Double click here',13,'to show bode plot ',13,'of controller']],...
		'Mask Display','Closed-Loop\nNyquist',...
		'Mask Type','')
set_param([sys,'/',['Double click here',13,'to show bode plot ',13,'of controller']],...
		'Mask Dialogue','eval(''if ~exist(''''ae''''), printf(''''Must Load Data & Desgin First''''), else,[x,y,z,w]=feedback(a,b,c,d,ae,be,ce,de,-1); clg, nyquist(x,y,z,w); end'')')
set_param([sys,'/',['Double click here',13,'to show bode plot ',13,'of controller']],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Double click here',13,'to show bode plot ',13,'of controller'].

set_param([sys,'/',['Double click here',13,'to show bode plot ',13,'of controller']],...
		'hide name',0,...
		'position',[361,277,442,318])


%     Subsystem  ['Double click here',13,'to show zero-pole',13,'plot of closed-loop4'].

new_system([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of closed-loop4']])
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of closed-loop4']],'Location',[2,439,106,512])
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of closed-loop4']],...
		'Mask Display','Controller\nBode Plot',...
		'Mask Type','')
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of closed-loop4']],...
		'Mask Dialogue','eval(''if ~exist(''''ae''''),fprintf(''''\nMust Load Data & Design First\n''''),else  [x,y,w]=bode(ae,be,ce,de); clg; subplot(211); loglog(w,x); subplot(212); semilogx(w,y); subplot(111); end'')')
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of closed-loop4']],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Double click here',13,'to show zero-pole',13,'plot of closed-loop4'].

set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of closed-loop4']],...
		'hide name',0,...
		'position',[281,277,353,318])


%     Subsystem  ['Double click here',13,'to start loading data',13,'and mu-syn design1'].

new_system([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design1']])
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design1']],'Location',[2,439,106,512])
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design1']],...
		'Mask Display','Re-Design',...
		'Mask Type','')
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design1']],...
		'Mask Dialogue','eval(''if ~exist(''''obalreal''''),fprintf(''''\nMust be licensed for RCT Toolbox\n''''), else, fprintf(''''\nCtrl_C to abort RCT Calculation\n\n''''); hinfdes1; end'')')
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design1']],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Double click here',13,'to start loading data',13,'and mu-syn design1'].

set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design1']],...
		'hide name',0,...
		'position',[102,277,177,318])


%     Subsystem  ['Double click here',13,'to show bode plot',13,'of closed-loop3'].

new_system([sys,'/',['Double click here',13,'to show bode plot',13,'of closed-loop3']])
set_param([sys,'/',['Double click here',13,'to show bode plot',13,'of closed-loop3']],'Location',[2,439,106,512])
set_param([sys,'/',['Double click here',13,'to show bode plot',13,'of closed-loop3']],...
		'Mask Display','Closed-Loop\nBode Plot',...
		'Mask Type','')
set_param([sys,'/',['Double click here',13,'to show bode plot',13,'of closed-loop3']],...
		'Mask Dialogue','eval(''if ~exist(''''ae''''),fprintf(''''\nMust Load Data & Design First\n''''),else [x,y,z,w]=series(a,b,c,d,ae,be,ce,de);[x,y,z,w]=cloop(x,y,z,w,-1); [x,y,w]=bode(x,y,z,w); clg; subplot(211); loglog(w,x(:,1)); subplot(212); semilogx(w,y(:,1)); subplot(111);  end'')')
set_param([sys,'/',['Double click here',13,'to show bode plot',13,'of closed-loop3']],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Double click here',13,'to show bode plot',13,'of closed-loop3'].

set_param([sys,'/',['Double click here',13,'to show bode plot',13,'of closed-loop3']],...
		'hide name',0,...
		'position',[188,277,269,318])


%     Subsystem  ['Double click here',13,'to start loading data',13,'and mu-syn design'].

new_system([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design']])
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design']],'Location',[2,439,106,512])
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design']],...
		'Mask Display','Re-Load\nData',...
		'Mask Type','')
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design']],...
		'Mask Dialogue','eval(''if ~exist(''''obalreal''''),fprintf(''''\nMust be licensed for RCT Toolbox\n''''), else, fprintf(''''\nCtrl_C to abort RCT Calculation\n\n''''); hinfdata; end'')')
set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design']],...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Double click here',13,'to start loading data',13,'and mu-syn design'].

set_param([sys,'/',['Double click here',13,'to start loading data',13,'and mu-syn design']],...
		'hide name',0,...
		'position',[23,275,92,317])


%     Subsystem  ['Double click here',13,'to show zero-pole',13,'plot of controller'].

new_system([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of controller']])
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of controller']],'Location',[2,439,106,512])
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of controller']],...
		'Mask Display','Controller\nNyquist',...
		'Mask Type','')
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of controller']],...
		'Mask Dialogue','eval(''if ~exist(''''ae''''), printf(''''Must Load Data & Desgin First''''), else,clg; nyquist(ae,be,ce,de), end'')',...
		'Mask Translate','')
set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of controller']],...
		'Mask Help','')


%     Finished composite block ['Double click here',13,'to show zero-pole',13,'plot of controller'].

set_param([sys,'/',['Double click here',13,'to show zero-pole',13,'plot of controller']],...
		'hide name',0,...
		'position',[450,278,521,318])

add_block('built-in/Note',[sys,'/','* Curves inside weighting function blocks are the weighting function bode plot'])
set_param([sys,'/','* Curves inside weighting function blocks are the weighting function bode plot'],...
		'position',[299,335,300,336])
add_line(sys,[305,45;545,45])
add_line(sys,[380,155;490,155;490,140;545,140])
add_line(sys,[400,155;400,225;90,225;90,170;105,170])
add_line(sys,[400,225;420,225])
add_line(sys,[540,225;550,225])
add_line(sys,[380,155;490,155;490,185;540,185])
add_line(sys,[300,155;335,155])
add_line(sys,[310,155;310,90;355,90])
add_line(sys,[80,155;105,155])
add_line(sys,[70,95;85,95;85,140;105,140])
add_line(sys,[140,155;170,155])
add_line(sys,[140,155;155,155;155,45;190,45])
add_line(sys,[475,90;540,90])
% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
