function [ret,x0,str,ts,xts]=musyndm(t,x,u,flag);
%MUSYNDM	is the M-file description of the SIMULINK system named MUSYNDM.
%	The block-diagram can be displayed by typing: MUSYNDM.
%
%	SYS=MUSYNDM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes MUSYNDM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling MUSYNDM with a FLAG of zero:
%	[SIZES]=MUSYNDM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[614,91,788,418])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Mu-Analysis and Synthesis',13,'Toolbox Demo']])
set_param([sys,'/',['Mu-Analysis and Synthesis',13,'Toolbox Demo']],...
		'position',[90,22,95,27])


%     Subsystem  ['Mu-Synthesis',13,'Design, Case2'].

new_system([sys,'/',['Mu-Synthesis',13,'Design, Case2']])
set_param([sys,'/',['Mu-Synthesis',13,'Design, Case2']],'Location',[-10,380,117,533])
set_param([sys,'/',['Mu-Synthesis',13,'Design, Case2']],...
		'Mask Display','MuSyn\nDemo2',...
		'Mask Dialogue','eval(''if ~exist(''''mu''''); fprintf(''''\nMust be licensed for MuSyn Toolbox\n''''), else, mudata2; musyndm2; end;'')')


%     Finished composite block ['Mu-Synthesis',13,'Design, Case2'].

set_param([sys,'/',['Mu-Synthesis',13,'Design, Case2']],...
		'position',[55,150,106,193])


%     Subsystem  ['Mu-Synthesis',13,'Design, MIMO'].

new_system([sys,'/',['Mu-Synthesis',13,'Design, MIMO']])
set_param([sys,'/',['Mu-Synthesis',13,'Design, MIMO']],'Location',[-10,380,117,533])
set_param([sys,'/',['Mu-Synthesis',13,'Design, MIMO']],...
		'Mask Display','MuSyn\nDemo3',...
		'Mask Dialogue','eval(''if ~exist(''''mu''''), fprintf(''''\nMust be licensed for MuSyn Toolbox\n''''), else, mudata3; musyndm3; end;'')')


%     Finished composite block ['Mu-Synthesis',13,'Design, MIMO'].

set_param([sys,'/',['Mu-Synthesis',13,'Design, MIMO']],...
		'position',[55,240,106,283])


%     Subsystem  ['Mu-Synthesis',13,'Design, Case 1'].

new_system([sys,'/',['Mu-Synthesis',13,'Design, Case 1']])
set_param([sys,'/',['Mu-Synthesis',13,'Design, Case 1']],'Location',[-10,380,117,533])
set_param([sys,'/',['Mu-Synthesis',13,'Design, Case 1']],...
		'Mask Display','MuSyn\nDemo1',...
		'Mask Dialogue','eval(''if ~exist(''''mu''''),fprintf(''''\nMust be licensed for MuSyn Toolbox\n''''), else, mudata1; musyndm1; end;'')')


%     Finished composite block ['Mu-Synthesis',13,'Design, Case 1'].

set_param([sys,'/',['Mu-Synthesis',13,'Design, Case 1']],...
		'position',[55,64,106,107])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
