% SIMULINK model analysis and construction functions.
% Version 1.3c   15-August-94
%
% Simulation.
%   adams    - Adams' method.
%   euler    - Euler's method.
%   gear     - Gear's method.
%   linsim   - Linear dynamics extraction method.
%   rk23     - Runge-Kutta third order method.
%   rk45     - Runge-Kutta fifth order method.
%
% Linearization and trimming.
%   linmod     - Extract linear model from continuous-time system.
%   linmod2    - Extract linear model, advanced method. 
%   dlinmod    - Extract linear model from discrete-time system.
%   trim       - Find steady-state operating point.
%
% Model Construction.
%   new_system   - Create new empty model window.
%   open_system  - Open existing model or block.
%   close_system - Close open model or block.
%   add_block    - Add new block.
%   add_line     - Add new line. 
%   delete_block - Remove block.
%   delete_line  - Remove line.
%   set_param    - Set parameter values for model or block.
%   get_param    - Get simulation parameter values from model.
%   bdclose      - Close a SIMULINK window.
%   bdresize     - Resize block diagram in an existing window.
%   bdreline     - Redraw lines in an existing SIMULINK window.
%   bdroot       - Root level model name.
%   gcb          - Get the name of the current block.
%   mfilename    - Currently executing M-file name.
%   iconedit     - Design block icons using ginput function.
%
% See also BLOCKS and SIMDEMOS.

% The functions listed below this point are utility routines that are
% used by the above functions. They are NOT ordinarily called directly
% by the user.
%
% Conversion functions.
%   c2d	       - Continuous to discrete time.
%   d2ci       - Discrete to continuous time.
%   d2d        - Discrete to discrete time with different sample rate.
%   dtf2ss     - Discrete transfer function to discrete state-space.
%   ss2tf      - State-space to transfer function.
%   ss2zp      - State-space to zero-pole.
%   tf2ss      - Transfer function to state-space.
%   tf2zp      - Transfer function to zero-pole.
%   zp2ss      - Zero-pole to state-space.
%   zp2tf      - Zero-pole to transfer function.
%
% Optimization and matrix math.
%   constr     - Constrained minimum of function of several variables.
%   expme      - Calculate matrix exponentials for LINSIM.
%   graderr    - Check gradient discrepancy in optimization routines. 
%   logm2      - Matrix natural logarithm of X.
%   qp         - Quadratic programming. 
%
% Miscellaneous.
%   abcdchk    - Check A,B,C,D dimensional consistency.
%   plotsim    - Utility called by integrators to plot graphs.
%   simver     - Specify SIMLINK version in which model is saved.
%   tfchk      - Check for transfer function consistency.
%   trimfun    - Utility used by TRIM.
%   linall     - Utility used by DLINMOD.
%   lineext    - Utility used by AUTOLINE.
%   linemima   - Utility used by AUTOLINE.
%   linedir    - Utility used by AUTOLINE.
%   accelopt   - Acceleration options dialog box.
%   mkaccel    - Forces MEX-file to be built for accelerator.
%   blkxchk    - Check whether a line crosses a block.
%   autoline   - Connect two blocks using autorouting.

% Copyright (c) 1990-94 by The MathWorks, Inc.
