function F = fourier(f,w,t)
%FOURIER Fourier integral transform.
%	F = FOURIER(f) is the Fourier transform of the symbolic expression f,
%	    F(w) = int(f(t)*exp(-i*w*t),'t',-inf,inf)
%	F = FOURIER(f,'v') is a function of 'v' instead of 'w'.
%	F = FOURIER(f,'v','x') assumes f is a function of 'x' instead of 't'.
%	F = FOURIER, with no input arguments, transforms the previous result.
%
%	Examples:
%	    fourier exp(-t)*Heaviside(t)    1/(1+i*w)
%	    fourier exp(-t^2)               pi^(1/2)*exp(-1/4*w^2)
%
%	See also INVFOURIER, LAPLACE, ZTRANS.

%	Copyright (c) 1993-95 by The MathWorks, Inc.

if nargin == 0
   f = maple('"');
elseif strcmp(f,'ans')
   f = maple('"');
end
if nargin < 2
   w = 'w';
end
if nargin < 3
   t = symvar(f,'t');
end
F = maple('fourier',f,t,w);
