function y = mfunlist
%MFUNLIST Special functions for MFUN.
%	The following special functions are listed in alphabetical order
%	according to the third column. n denotes an integer argument, 
%	x denotes a real argument, and z denotes a complex argument. For 
%	more detailed descriptions of the functions, including any 
%	argument restrictions, see the Reference Manual, or use MHELP.
%
%bernoulli      n       Bernoulli Numbers
%bernoulli      n,z     Bernoulli Polynomials
%BesselI        x1,x    Bessel Function of the First Kind
%BesselJ        x1,x    Bessel Function of the First Kind
%BesselK        x1,x    Bessel Function of the Second Kind
%BesselY        x1,x    Bessel Function of the Second Kind
%Beta           z1,z2   Beta Function
%binomial       x1,x2   Binomial Coefficients
%LegendreKc     x       Complete Elliptic Integral of First Kind
%LegendreEc     x       Complete Elliptic Integral of Second Kind
%LegendrePic    x1,x    Complete Elliptic Integral of Third Kind
%LegendreKc1    x       LegendreKc using Complementary Modulus
%LegendreEc1    x       LegendreEc using Complementary Modulus
%LegendrePic1   x1,x    LegendrePic using Complementary Modulus
%erfc           z       Complementary Error Function
%erfc           n,z     Complementary Error Function's Iterated Integrals
%Ci             z       Cosine Integral
%dawson         x       Dawson's Integral
%Psi            z       Digamma Function
%dilog          x       Dilogarithm Integral
%erf            z       Error Function 
%euler          n       Euler Numbers
%euler          n,z     Euler Polynomials
%Ei             x       Exponential Integral
%Ei             n,z     Exponential Integral
%FresnelC       x       Fresnel Cosine Integral 
%FresnelS       x       Fresnel Sine Integral 
%GAMMA          z       Gamma Function 
%harmonic       n       Harmonic Function
%Chi            z       Hyperbolic Cosine Integral
%Shi            z       Hyperbolic Sine Integral
%hypergeom      X1,X2   (Generalized) Hypergeometric Function
%LegendreF      x,x1    Incomplete Elliptic Integral of First Kind
%LegendreE      x,x1    Incomplete Elliptic Integral of Second Kind
%LegendrePi     x,x2,x1 Incomplete Elliptic Integral of Third Kind
%GAMMA          z1,z2   Incomplete Gamma Function
%W              z       Lambert's W Function
%W              n,z     Lambert's W Function
%lnGAMMA        z       Logarithm of the Gamma function
%Li             x       Logarithmic Integral
%Psi            n,z     Polygamma Function
%Ssi            z       Shifted Sine Integral
%Si             z       Sine Integral
%Zeta           x       (Riemann) Zeta Function
%Zeta           n,x     (Riemann) Zeta Function
%Zeta           n,x,x1  (Riemann) Zeta Function
%
%       Orthogonal Polynomials (Extended Symbolic Math Toolbox only)
%T      n,x             Chebyshev of the First Kind
%U      n,x             Chebyshev of the Second Kind
%G      n,x1,x          Gegenbauer
%H      n,x             Hermite
%P      n,x1,x2,x       Jacobi
%L      n,x             Laguerre
%L      n,x1,x          Generalized Laguerre
%P      n,x             Legendre
%
%           See also MFUN, MHELP.

%	Copyright (c) 1993-95 by The MathWorks, Inc.
%	$Revision: 1.9 $  $Date: 1995/03/01 21:38:53 $
